# pyBiblio
pyBiblio is a Python library providing a set of functions to compute basic bibliometric measures from Web of Science files.

Documentation available at https://romerogroup.github.io/pyBiblio/
